<template>
  <div>
    <el-dialog title="路线列表" width="800px" :visible.sync="dialogTableVisible">
      <el-form :inline="true" :model="form">
        <el-form-item label="" :label-width="formLabelWidth">
          <el-input v-model="form.name" placeholder="请输入名称" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item label="" :label-width="formLabelWidth">
          <el-button type="primary" @click="handleSearch">搜索</el-button>
        </el-form-item>
      </el-form>
      <div style="margin-bottom: 16px">
        <el-button type="success" @click="handleAdd">新建</el-button>
        <!-- <el-button type="danger" plain @click="handleDel">删除</el-button> -->
      </div>
      <el-table
        border
        ref="multipleTable"
        :data="tableData"
        tooltip-effect="dark"
        style="width: 100%"
        @selection-change="handleSelectionChange"
      >
        <el-table-column type="selection" width="55"> </el-table-column>
        <el-table-column label="序号" type="index" width="80" />
        <el-table-column label="路线名称">
          <template slot-scope="scope">{{ scope.row.name }}</template>
        </el-table-column>
        <el-table-column prop="name" label="所属项目">
          <template slot-scope="scope">{{ scope.row.projectName }}</template>
        </el-table-column>
        <!-- <el-table-column prop="roadLength" label="长度（千米）">
          <template slot-scope="scope">{{ scope.row.roadLength }}</template>
        </el-table-column> -->
        <el-table-column label="操作" width="175">
          <template slot-scope="scope">
            <el-button type="primary" size="mini" @click="handleMap(scope.row)">地图查看</el-button>
            <el-button type="danger" size="mini" plain @click="handleDel(scope.row)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>
    </el-dialog>
  </div>
</template>
<script>
import { searchRoadmaps, delRoadmaps } from "@/api/malasong-route-controller";
import { getProjects } from "@/api/projects-controller";

export default {
  name: "RouteList",
  data() {
    return {
      projects: [],
      dialogTableVisible: false,
      formLabelWidth: "70px",
      form: {
        name: "",
      },
      currentPage: 1,
      pageSize: 10000,
      tableData: [],
      multipleSelection: [],
    };
  },
  mounted() {},
  methods: {
    getList() {
      const params = {
        name: this.form.name,
        projectIds: this.projects.map((e) => e.id),
      };
      searchRoadmaps(params)
        .then((res) => {
          const { data } = res;
          this.tableData = data;
        })
        .catch((err) => {
          console.log("🚀 ~ searchRoadmaps ~ err:", err);
        });
    },
    async setVisible() {
      this.dialogTableVisible = true;
      this.projects = await getProjects({
        pageIndex: 1,
        pageSize: 10000,
        forExport: true,
        keyword: null,
        superviseDepartIds: [],
      });
      this.getList();
    },
    handleSelectionChange(val) {
      this.multipleSelection = val;
    },
    handleSearch() {
      this.getList();
    },
    handleMap(row) {
      this.dialogTableVisible = false;
      this.$emit("viewRoute", row);
    },
    handleAdd() {
      this.dialogTableVisible = false;
      this.$emit("addRoute");
    },
    handleDel(row) {
      delRoadmaps(row.id).then((res) => {
        this.$message.success("操作成功");
        this.getList();
      });
    },
  },
};
</script>
